package samples;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import com.obs.services.ObsClient;
import com.obs.services.ObsConfiguration;
import com.obs.services.exception.ObsException;
import com.obs.services.model.DeleteObjectsRequest;
import com.obs.services.model.DeleteObjectsResult;
import com.obs.services.model.DeleteObjectsResult.DeleteObjectResult;
import com.obs.services.model.DeleteObjectsResult.ErrorResult;
import com.obs.services.model.KeyAndVersion;
import com.obs.services.model.ListObjectsRequest;
import com.obs.services.model.ObjectListing;
import com.obs.services.model.ObsObject;

/**
 * This sample demonstrates how to delete objects by specified prefix under specified bucket 
 * from OBS using the OBS SDK for Java.
 */
public class DeleteObjectsByPrefixSample {
	
	private static final String endPoint = "yourdomainname";

	private static final String ak = "*** Provide your Access Key ***";

	private static final String sk = "*** Provide your Secret Key ***";

	private static ObsClient obsClient;

	private static String bucketName = "my-obs-bucket-demo";
	
	private static String prefix = "yourprefix";
	
	public static List<DeleteObjectsResult> deleteObjectsByPrefix(String bucketName, String prefix) {
		List<DeleteObjectsResult> results = new ArrayList<DeleteObjectsResult>();
		
		ListObjectsRequest listObjectsRequest = new ListObjectsRequest(bucketName);
		listObjectsRequest.setPrefix(prefix);
		listObjectsRequest.setMaxKeys(1);
		ObjectListing objectList;
		
		do {
			objectList = obsClient.listObjects(listObjectsRequest);
			DeleteObjectsRequest request = new DeleteObjectsRequest();
			request.setBucketName(bucketName);
			request.setQuiet(false);
			
			KeyAndVersion[] kvs = new KeyAndVersion[objectList.getObjects().size()];
			int index = 0;
			for(ObsObject obj : objectList.getObjects()) {
				kvs[index++] = new KeyAndVersion(obj.getObjectKey());
				request.setKeyAndVersions(kvs);
			}
			DeleteObjectsResult result = obsClient.deleteObjects(request);
			results.add(result);
			listObjectsRequest.setMarker(objectList.getNextMarker());
		}while(objectList.isTruncated());


		return results;
	}

	public static void main(String[] args) throws IOException {

		ObsConfiguration config = new ObsConfiguration();
		config.setSocketTimeout(30000);
		config.setConnectionTimeout(10000);
		config.setEndPoint(endPoint);
		try {

			/*
			 * Constructs a obs client instance with your account for accessing OBS
			 */
			obsClient = new ObsClient(ak, sk, config);
			
			System.out.println("\nDeleting all objects by prefix\n");

			List<DeleteObjectsResult> results = deleteObjectsByPrefix(bucketName, prefix);
			
			for(DeleteObjectsResult result : results) {
				System.out.println("Delete results:");
				
				for (DeleteObjectResult object : result.getDeletedObjectResults()) {
					System.out.println("\t" + object);
				}
				
				System.out.println("Error results:");
				for (ErrorResult error : result.getErrorResults()) {
					System.out.println("\t" + error);
				}
			}

			System.out.println();

		} catch (ObsException e) {
			System.out.println("Response Code: " + e.getResponseCode());
			System.out.println("Error Message: " + e.getErrorMessage());
			System.out.println("Error Code:       " + e.getErrorCode());
			System.out.println("Request ID:      " + e.getErrorRequestId());
			System.out.println("Host ID:           " + e.getErrorHostId());
		} finally {
			if (obsClient != null) {
				try {
					/*
					 * Close obs client
					 */
					obsClient.close();
				} catch (IOException e) {
				}
			}
		}
	}
}
